# December 16, 2024 - Version 1.7.0

Please update PrismStudio via

```python
pip install prismstudio --upgrade
```

or

```python
pip install prismstudio==1.7.0
```


If you prefer to use Anaconda, please install PrismStudio using command below

```bash
conda config --add channels conda-forge
conda install -c prism39 prismstudio
```


---

## Change Log
- [MAJOR] Changed Securtiy Master Base IDs - WARNING: Please make sure to recreate the universe before use for this version.
- [MAJOR] Removed list input in ps.get_data
- [MINOR] Added RDC Primary


